@@ -8,7 +8,7 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 __all__ = ['generate_ai_plugins_classes']
 
-IF_PLUGINS = ["GWF092023", "MFW022023", "ACF082023", "GDF032022", "AAT052023", "ACS042023", "GLU062021", "GDP042022", "AHD062022", "COM032023", "GBA032023", "ABA092022", "TDM052022", "BOO032022", "ABK042023", "GDU102023", "ASF012023", "ZBA042022", "AAR072022", "AMM082023", "ATR122022", "ZDX112021", "ADB112022", "SOP072023", "GDQ112023", "ADF062021", "QLC092022", "ZLA112022", "ZRM082023", "ZSY062022", "ZML022023", "AQS012023", "DBT042023", "BAK092023", "UIP072021", "MBI042022", "ADP122022", "SFI122022", "TAB072023", "TER102023", "ZFN032022", "MFL022023", "ZVM062022", "AEC082022", "ASM0220223", "DBX032022", "RST062023", "GFU012023", "ADO112023", "SNF092022", "ICS032022", "GDR052023", "GDM082023", "GBQ102022", "AEM072022", "GVM062022"]
+IF_PLUGINS = ["ZBA042022", "AAR072022", "ABA092022", "ABY122023", "DBT042023", "ACS042023", "MBI042022", "SFI122022", "KBN062023", "OVM012024", "ATR122022", "ZVM062022", "ZSY062022", "ZFN032022", "ALM012024", "GWF092023", "RST062023", "QLC092022", "GDM082023", "ADY122023", "ACF082023", "SNF092022", "AAT052023", "ADF062021", "AEM072022", "BOO032022", "GDQ112023", "GBQ102022", "ABK042023", "ASM0220223", "ICS032022", "AMM082023", "ASF012023", "GDR052023", "ZDX112021", "ZRM082023", "BAK092023", "GFU012023", "GDF032022", "ADO112023", "GLU062021", "GBA032023", "DBX032022", "ZLA112022", "AEC082022", "ADP122022", "COM032023", "AQS012023", "ZML022023", "MFW022023", "GDU102023", "TAB072023", "ADB112022", "TDM052022", "GDP042022", "TER102023", "UIP072021", "GVM062022", "AHD062022", "SOP072023", "MFL022023"]
 
 
 imports_str = '''from aapi import *
